Building translators community
==============================

Community localization checklist
--------------------------------

.. versionadded:: 3.9

The :guilabel:`Community localization checklist` which can be found in the
menu of each component can give you guidance to make your
localization process easy for community translators.

.. image:: /screenshots/guide.png
